@@ -96,7 +96,7 @@ QEC Module Usage (NEW in v4.0.0):
     >>> print(f"Accuracy: {em.accuracy_original:.1f}% → {em.accuracy_mitigated:.1f}%")
 """
 
-__version__ = "5.3.6"
+__version__ = "5.7.3"
 __author__ = "BioQL Development Team / SpectrixRD"
 __email__ = "bioql@spectrixrd.com"
 __license__ = "MIT"
@@ -327,6 +327,122 @@ except ImportError:
     ResourceEstimator = None
     ResourceEstimation = None
 
+# NEW in v5.4.3 - CRISPR-QAI Module
+try:
+    from .crispr_qai import (
+        # Featurization
+        encode_guide_sequence,
+        guide_to_angles,
+        # Energy estimation
+        estimate_energy_collapse_simulator,
+        estimate_energy_collapse_braket,
+        estimate_energy_collapse_qiskit,
+        # Optimization
+        rank_guides_batch,
+        # Phenotype inference
+        infer_offtarget_phenotype,
+        # I/O
+        load_guides_csv,
+        save_results_csv,
+        # Safety
+        check_simulation_only,
+        # Adapters
+        QuantumEngine,
+        LocalSimulatorEngine,
+    )
+    HAVE_CRISPR_QAI = True
+except ImportError:
+    # CRISPR-QAI not available
+    encode_guide_sequence = None
+    guide_to_angles = None
+    estimate_energy_collapse_simulator = None
+    estimate_energy_collapse_braket = None
+    estimate_energy_collapse_qiskit = None
+    rank_guides_batch = None
+    infer_offtarget_phenotype = None
+    load_guides_csv = None
+    save_results_csv = None
+    check_simulation_only = None
+    QuantumEngine = None
+    LocalSimulatorEngine = None
+    HAVE_CRISPR_QAI = False
+
+# NEW in v5.6.0+ - Advanced Drug Discovery Modules
+try:
+    from .adme_predictor import (
+        predict_adme_toxicity,
+        predict_adme_local,
+        predict_toxicity_local,
+        ADMEResult,
+        ToxicityResult
+    )
+except ImportError:
+    predict_adme_toxicity = None
+    predict_adme_local = None
+    predict_toxicity_local = None
+    ADMEResult = None
+    ToxicityResult = None
+
+try:
+    from .bioisostere_db import (
+        suggest_bioisosteric_replacements,
+        BioisostereReplacement,
+        BIOISOSTERE_DATABASE
+    )
+except ImportError:
+    suggest_bioisosteric_replacements = None
+    BioisostereReplacement = None
+    BIOISOSTERE_DATABASE = None
+
+try:
+    from .similarity_search import (
+        similarity_search_pipeline,
+        search_chembl,
+        search_pubchem,
+        search_drugbank_local
+    )
+except ImportError:
+    similarity_search_pipeline = None
+    search_chembl = None
+    search_pubchem = None
+    search_drugbank_local = None
+
+try:
+    from .offtarget_panel import (
+        screen_offtargets,
+        OffTarget,
+        OFFTARGET_PANEL
+    )
+except ImportError:
+    screen_offtargets = None
+    OffTarget = None
+    OFFTARGET_PANEL = None
+
+try:
+    from .resistance_profiler import (
+        analyze_resistance_profile,
+        Mutation,
+        RESISTANCE_MUTATIONS
+    )
+except ImportError:
+    analyze_resistance_profile = None
+    Mutation = None
+    RESISTANCE_MUTATIONS = None
+
+try:
+    from .pipeline_orchestrator import run_complete_pipeline
+except ImportError:
+    run_complete_pipeline = None
+
+try:
+    from .pdb_generator import (
+        generate_docking_pdb,
+        PDBDockingGenerator
+    )
+except ImportError:
+    generate_docking_pdb = None
+    PDBDockingGenerator = None
+
 # Define what gets exported when using "from bioql import *"
 __all__ = [
     # Core functionality
@@ -395,6 +511,66 @@ if AdvancedErrorMitigation is not None:
         "AdvancedErrorMitigation", "ErrorMitigationResult", "demo_error_mitigation"
     ])
 
+# Add CRISPR-QAI modules if available
+if HAVE_CRISPR_QAI:
+    __all__.extend([
+        # Featurization
+        "encode_guide_sequence",
+        "guide_to_angles",
+        # Energy estimation
+        "estimate_energy_collapse_simulator",
+        "estimate_energy_collapse_braket",
+        "estimate_energy_collapse_qiskit",
+        # Optimization
+        "rank_guides_batch",
+        # Phenotype inference
+        "infer_offtarget_phenotype",
+        # I/O
+        "load_guides_csv",
+        "save_results_csv",
+        # Safety
+        "check_simulation_only",
+        # Adapters
+        "QuantumEngine",
+        "LocalSimulatorEngine",
+    ])
+
+# Add v5.6.0+ Advanced Drug Discovery modules if available
+if predict_adme_toxicity is not None:
+    __all__.extend([
+        "predict_adme_toxicity", "predict_adme_local", "predict_toxicity_local",
+        "ADMEResult", "ToxicityResult"
+    ])
+
+if suggest_bioisosteric_replacements is not None:
+    __all__.extend([
+        "suggest_bioisosteric_replacements", "BioisostereReplacement",
+        "BIOISOSTERE_DATABASE"
+    ])
+
+if similarity_search_pipeline is not None:
+    __all__.extend([
+        "similarity_search_pipeline", "search_chembl", "search_pubchem",
+        "search_drugbank_local"
+    ])
+
+if screen_offtargets is not None:
+    __all__.extend(["screen_offtargets", "OffTarget", "OFFTARGET_PANEL"])
+
+if analyze_resistance_profile is not None:
+    __all__.extend([
+        "analyze_resistance_profile", "Mutation", "RESISTANCE_MUTATIONS"
+    ])
+
+if run_complete_pipeline is not None:
+    __all__.append("run_complete_pipeline")
+
+if generate_docking_pdb is not None:
+    __all__.extend([
+        "generate_docking_pdb",
+        "PDBDockingGenerator"
+    ])
+
 
 def get_version() -> str:
     """Return the current version of BioQL."""
