@@ -21,6 +21,9 @@ __all__ = [
     "prepare_ligand",
     "prepare_receptor",
     "GeometryOptimizer",
+    "calculate_pharmaceutical_scores",
+    "PharmaceuticalScores",
+    "neutralize_smiles",
 ]
 
 # Lazy imports to avoid hard dependencies
@@ -44,4 +47,27 @@ class GeometryOptimizer:
         self._optimizer = _GeometryOptimizer()
 
     def optimize(self, *args, **kwargs):
-        return self._optimizer.optimize(*args, **kwargs)
\ No newline at end of file
+        return self._optimizer.optimize(*args, **kwargs)
+
+
+def calculate_pharmaceutical_scores(*args, **kwargs):
+    """Calculate pharmaceutical scores (Lipinski, QED, SA Score, etc.)."""
+    from .pharma_scores import calculate_pharmaceutical_scores as _calc_scores
+    return _calc_scores(*args, **kwargs)
+
+
+class PharmaceuticalScores:
+    """Pharmaceutical scoring for drug candidates."""
+
+    def __init__(self):
+        from .pharma_scores import PharmaceuticalScores as _PharmaScores
+        self._scorer = _PharmaScores()
+
+    def calculate_all(self, *args, **kwargs):
+        return self._scorer.calculate_all(*args, **kwargs)
+
+
+def neutralize_smiles(*args, **kwargs):
+    """Neutralize charged SMILES for AutoDock Vina compatibility."""
+    from .neutralize import neutralize_smiles as _neutralize
+    return _neutralize(*args, **kwargs)
\ No newline at end of file
