@@ -108,13 +108,47 @@ def prepare_ligand_pdbqt(smiles: str, output_pdbqt: Path) -> None:
     if mol is None:
         raise ValueError(f"SMILES inválido: {smiles}")
 
+    # Para PDBQT: BRUTAL SMILES-level neutralization
+    # AutoDock Vina CANNOT handle charged atoms
+    # Strategy: Work at SMILES level to remove charges, then reconstruct
+    import re
+
+    # Get canonical SMILES
+    clean_smiles = Chem.MolToSmiles(mol)
+
+    # Remove all charge indicators from SMILES
+    # [X+] -> [X], [X-] -> [X], [X+n] -> [X], [X-n] -> [X]
+    neutral_smiles = re.sub(r'\[([^]]+?)[-+][0-9]*\]', r'[\1]', clean_smiles)
+
+    # Try to rebuild from neutralized SMILES
+    try:
+        mol = Chem.MolFromSmiles(neutral_smiles)
+        if mol is None:
+            # If neutralized SMILES fails, try original
+            mol = Chem.MolFromSmiles(smiles)
+    except:
+        # Fallback to original
+        mol = Chem.MolFromSmiles(smiles)
+
     # Añadir hidrógenos
     mol = Chem.AddHs(mol)
 
     # Generar conformación 3D
     params = AllChem.ETKDGv3()
     params.randomSeed = 42  # Reproducibilidad
-    AllChem.EmbedMolecule(mol, params)
+
+    # Intentar embedding 3D (puede fallar con moléculas aromáticas complejas)
+    try:
+        embed_result = AllChem.EmbedMolecule(mol, params)
+        if embed_result != 0:
+            # Embedding falló, intentar con ETKDG v2
+            params_v2 = AllChem.ETKDG()
+            params_v2.randomSeed = 42
+            embed_result = AllChem.EmbedMolecule(mol, params_v2)
+            if embed_result != 0:
+                raise ValueError(f"Failed to generate 3D conformer for SMILES: {smiles}")
+    except Exception as e:
+        raise ValueError(f"3D embedding failed: {e}")
 
     # Optimizar geometría
     AllChem.UFFOptimizeMolecule(mol, maxIters=500)
@@ -144,8 +178,18 @@ def prepare_ligand_pdbqt(smiles: str, output_pdbqt: Path) -> None:
             f_out.write("ROOT\n")
             for line in pdb_lines:
                 if line.startswith(('ATOM', 'HETATM')):
-                    # Mantener formato PDB estándar
-                    f_out.write(line)
+                    # Clean element column (last chars in PDB format)
+                    # RDKit writes "N1+", "C1", etc - Vina needs just "N", "C"
+                    line = line.rstrip('\n')  # Remove newline
+                    # Extract element: keep only letters at end (remove digits and +/-)
+                    import re
+                    # Find element at end: 1-2 letters, possibly followed by digits/charges
+                    match = re.search(r'([A-Z][a-z]?)[0-9]*[+-]*\s*$', line)
+                    if match:
+                        element = match.group(1)  # Just the letters (e.g., "N" from "N1+")
+                        # Replace the end of line with clean element
+                        line = line[:match.start()] + f"{element:>2}"
+                    f_out.write(line + '\n')
             f_out.write("ENDROOT\n")
             f_out.write("TORSDOF 0\n")
 
